@@ -5,8 +5,8 @@ from cad_parser.definitions import Element, Tooth
 class TestElement(unittest.TestCase):
     def test_constructor(self):
         teeth = [
-            Tooth(1, 'A1', None, None, 'AnatomicCrown'),
-            Tooth(2, 'A2', None, None, 'AnatomicCrown')
+            Tooth(fdi=1, color='A1', implant_system=None, implant_type=None, is_anatomical=None, type='AnatomicCrown'),
+            Tooth(fdi=2, color='A2', implant_system=None, implant_type=None, is_anatomical=None, type='AnatomicCrown')
         ]
         element = Element(file_name='foo.stl', material='gold', color='orange', height=7.838345409284646, is_screw_retained=None, type=None, teeth=teeth)
 
